ONOS-3296: Support continuous type resources

Change-Id: I155e41e7a7c1750ff45986a55bedab353485d3fa
diff --git a/core/api/src/main/java/org/onosproject/net/newresource/ResourceService.java b/core/api/src/main/java/org/onosproject/net/newresource/ResourceService.java
index 966de50..79a7bba 100644
--- a/core/api/src/main/java/org/onosproject/net/newresource/ResourceService.java
+++ b/core/api/src/main/java/org/onosproject/net/newresource/ResourceService.java
@@ -126,13 +126,13 @@
     boolean release(ResourceConsumer consumer);
 
     /**
-     * Returns resource allocation of the specified resource.
+     * Returns resource allocations of the specified resource.
      *
      * @param resource resource to check the allocation
      * @return allocation information enclosed by Optional.
      * If the resource is not allocated, the return value is empty.
      */
-    Optional<ResourceAllocation> getResourceAllocation(ResourcePath resource);
+    List<ResourceAllocation> getResourceAllocation(ResourcePath resource);
 
     /**
      * Returns allocated resources being as children of the specified parent and being the specified resource type.
@@ -126,13 +126,13 @@
      *
      * @param resource resource to check the allocation
-     * @return allocation information enclosed by Optional.
-     * If the resource is not allocated, the return value is empty.
+     * @return list of allocation information.
+     * If the resource is not allocated, the return value is an empty list.
      */